@@ -56,7 +56,7 @@ static CreateFileDialogHelperFunc createFileDialogHelper = nullptr;
 
 LXQtPlatformTheme::LXQtPlatformTheme():
     iconFollowColorScheme_(true)
-    , settingsWatcher_(NULL)
+    , settingsWatcher_(nullptr)
 {
     loadSettings();
     // Note: When the plugin is loaded, it seems that the app is not yet running and
@@ -238,8 +238,8 @@ QPlatformDialogHelper *LXQtPlatformTheme::createPlatformDialogHelper(DialogType
 
         // The createFileDialogHelper() method is dynamically loaded from libfm-qt on demand
         if(createFileDialogHelper == nullptr) {
-            // try to dynamically load libfm-qt.so
-            QLibrary libfmQtLibrary{QLatin1String("libfm-qt")};
+            // try to dynamically load versioned libfm-qt.so
+            QLibrary libfmQtLibrary{QLatin1String(LIB_FM_QT_SONAME)};
             libfmQtLibrary.load();
             if(!libfmQtLibrary.isLoaded()) {
                 return nullptr;
